==> vajram-7.0.2-20240614.130316-1-sources.jar: com/flipkart/krystal/vajram/das/VajramIndex.java <==
package com.flipkart.krystal.vajram.das;

import com.flipkart.krystal.vajram.Vajram;
import com.flipkart.krystal.vajram.VajramID;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableMap;
import java.util.HashMap;
import java.util.Map;
import java.util.Optional;
import java.util.Set;

/**
 * An index of vajrams which supports their retrieval by an access spec in sublinear time complexity
 * wrt. to the number of vajrams in the index.
 */
public final class VajramIndex {
  private static final Set<Class<? extends DataAccessSpec>> SUPPORTED_ACCESS_SPECS =
      Set.of(VajramID.class, GraphQl.class);
  private final Map<Class<? extends DataAccessSpec>, AccessSpecIndex<? extends DataAccessSpec>>
      accessSpecIndices = new HashMap<>();

  public VajramIndex() {
    SUPPORTED_ACCESS_SPECS.forEach(
        aClass -> {
          if (VajramID.class.equals(aClass)) {
            accessSpecIndices.put(VajramID.class, new VajramIDIndex());
          } else if (GraphQl.class.equals(aClass)) {
            accessSpecIndices.put(GraphQl.class, new GraphQlIndex());
          }
        });
  }

  public <T extends DataAccessSpec> AccessSpecMatchingResult<T> getVajrams(T accessSpec) {
    //noinspection unchecked
    return Optional.ofNullable((AccessSpecIndex<T>) accessSpecIndices.get(accessSpec.getClass()))
        .map(index -> index.getVajrams(accessSpec))
        .orElse(
            new AccessSpecMatchingResult<>(
                ImmutableMap.of(), ImmutableMap.of(), ImmutableList.of(accessSpec)));
  }

  public void add(Vajram vajram) {
    accessSpecIndices.values().forEach(accessSpecIndex -> accessSpecIndex.add(vajram));
  }
}

==> vajram-8.0.0-20241203.183246-8-sources.jar: com/flipkart/krystal/vajram/das/VajramIndex.java <==
package com.flipkart.krystal.vajram.das;

import com.flipkart.krystal.vajram.VajramID;
import com.flipkart.krystal.vajram.exec.VajramDefinition;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableMap;
import java.util.HashMap;
import java.util.Map;
import java.util.Optional;
import java.util.Set;

/**
 * An index of vajrams which supports their retrieval by an access spec in sublinear time complexity
 * wrt. to the number of vajrams in the index.
 */
public final class VajramIndex {
  private static final Set<Class<? extends DataAccessSpec>> SUPPORTED_ACCESS_SPECS =
      Set.of(VajramID.class, GraphQl.class);
  private final Map<Class<? extends DataAccessSpec>, AccessSpecIndex<? extends DataAccessSpec>>
      accessSpecIndices = new HashMap<>();

  public VajramIndex() {
    SUPPORTED_ACCESS_SPECS.forEach(
        aClass -> {
          if (VajramID.class.equals(aClass)) {
            accessSpecIndices.put(VajramID.class, new VajramIDIndex());
          } else if (GraphQl.class.equals(aClass)) {
            accessSpecIndices.put(GraphQl.class, new GraphQlIndex());
          }
        });
  }

  public <T extends DataAccessSpec> AccessSpecMatchingResult<T> getVajrams(T accessSpec) {
    @SuppressWarnings("unchecked")
    AccessSpecIndex<T> accessSpecIndex =
        (AccessSpecIndex<T>) accessSpecIndices.get(accessSpec.getClass());
    return Optional.ofNullable(accessSpecIndex)
        .map(index -> index.getVajrams(accessSpec))
        .orElse(
            new AccessSpecMatchingResult<>(
                ImmutableMap.of(), ImmutableMap.of(), ImmutableList.of(accessSpec)));
  }

  public void add(VajramDefinition vajramDefinition) {
    accessSpecIndices.values().forEach(accessSpecIndex -> accessSpecIndex.add(vajramDefinition));
  }
}
